@@ -13,6 +13,15 @@ from feincms.utils import get_object
 class RichTextContentAdminForm(ItemEditorForm):
     text = forms.CharField(widget=forms.Textarea, required=False, label=_('text'))
 
+    feincms_item_editor_classes = {
+        'text': 'tinymce',
+    }
+
+    def __init__(self, *args, **kwargs):
+        super(RichTextContentAdminForm, self).__init__(*args, **kwargs)
+        for field in self.feincms_item_editor_classes.keys():
+            self.fields[field].widget.attrs.update({'class': 'item-richtext-%s' % self.feincms_item_editor_classes[field]})
+
     #: If FEINCMS_TIDY_ALLOW_WARNINGS_OVERRIDE allows, we'll convert this into
     # a checkbox so the user can choose whether to ignore HTML validation
     # warnings instead of fixing them:
@@ -61,7 +70,11 @@ class RichTextContent(models.Model):
     form = RichTextContentAdminForm
     feincms_item_editor_form = RichTextContentAdminForm
 
-    feincms_item_editor_context_processors = ( lambda x: dict(TINYMCE_JS_URL = settings.TINYMCE_JS_URL), )
+    feincms_item_editor_context_processors = (
+        lambda x: dict(TINYMCE_JS_URL = settings.TINYMCE_JS_URL),
+        lambda x: dict(TINYMCE_CONTENT_CSS_URL = settings.TINYMCE_CONTENT_CSS_URL),
+        lambda x: dict(TINYMCE_LINK_LIST_URL = settings.TINYMCE_LINK_LIST_URL),
+    )
     feincms_item_editor_includes = {
         'head': [ settings.TINYMCE_CONFIG_URL ],
         }
@@ -79,12 +92,14 @@ class RichTextContent(models.Model):
     def save(self, *args, **kwargs):
         # TODO: Move this to the form?
         if getattr(self, 'cleanse', False):
-            from feincms.utils.cleanse import cleanse_html
+            from feincms.utils.html.cleanse import cleanse_html
             self.text = cleanse_html(self.text)
         super(RichTextContent, self).save(*args, **kwargs)
 
     @classmethod
-    def initialize_type(cls):
+    def initialize_type(cls, cleanse=False):
+        cls.cleanse = cleanse
+
         # TODO: Move this into somewhere more generic:
         if settings.FEINCMS_TIDY_HTML:
             # Make sure we can load the tidy function without dependency failures:
@@ -92,3 +107,26 @@ class RichTextContent(models.Model):
                 get_object(settings.FEINCMS_TIDY_FUNCTION)
             except ImportError, e:
                 raise ImproperlyConfigured("FEINCMS_TIDY_HTML is enabled but the HTML tidy function %s could not be imported: %s" % (settings.FEINCMS_TIDY_FUNCTION, e))
+
+
+class CkEditorRichTextContentAdminForm(RichTextContentAdminForm):
+    feincms_item_editor_classes = {
+        'text': 'ckeditor',
+    }
+
+class CkEditorRichTextContent(RichTextContent):
+    form = CkEditorRichTextContentAdminForm
+    feincms_item_editor_form = CkEditorRichTextContentAdminForm
+
+    feincms_item_editor_context_processors = (
+        lambda x: dict(CKEDITOR_JS_URL = settings.CKEDITOR_JS_URL),
+    )
+
+    feincms_item_editor_includes = {
+        'head': [ settings.CKEDITOR_CONFIG_URL, ],
+    }
+
+    class Meta(RichTextContent.Meta):
+        abstract = True
+        verbose_name = _('rich text (ckeditor)')
+        verbose_name_plural = _('rich texts (ckeditor)')
